@@ -18,7 +18,7 @@ CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
               help='STDOUT logging level -> [DEBUG | INFO | WARN |WARNING | ERROR | CRITICAL]')
 @click.option('--file_loglevel', '-lf', type=click.STRING, default="INFO", show_default=True, 
               help='File logging level -> [DEBUG | INFO | WARN| WARNING | ERROR | CRITICAL]')
-@click.option('--verbose', '-v', is_flag=True, show_default=True, default=False, help='Turn on/off progress bar')
+@click.option('--verbose', '-v', is_flag=True, show_default=True, default=True, help='Turn on/off progress bar')
 def cli(domain, 
          reports_path, 
          reports_list=[],
